Crate kcr_tinkerbell_org

Crate kcr_tinkerbell_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the tinkerbell.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

tinkerbell.org/v1alpha1

  • Stack
  • Hardware
  • OSIE
  • Template
  • Workflow

tinkerbell.org/v1alpha2

  • Hardware
  • OSIE
  • Template
  • Workflow

Modules

v1alpha1
v1alpha2