pub struct StackServicesSmeeImage {
pub repository: Option<String>,
pub tag: Option<String>,
}Expand description
Image specifies the image repo and tag for Smee.
Fields
repository: Option<String>Repository is used to set the image repository for tinkerbell services.
tag: Option<String>Tag is used to set the image tag for tinkerbell services.