This crate contains kube-rs compatible bindings for Kubernetes custom resources for the tinkerbell.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
tinkerbell.org/v1alpha1
StackHardwareOSIETemplateWorkflow
tinkerbell.org/v1alpha2
HardwareOSIETemplateWorkflow